Class: Pod::ExternalSources::AbstractExternalSource

Inherits:
Object
  • Object
show all
Defined in:
lib/cocoapods/external_sources.rb

Overview

Abstract class that defines the common behaviour of external sources.

Instance Attribute Summary collapse

Subclasses hooks collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, params, podfile_path) ⇒ AbstractExternalSource

Returns a new instance of AbstractExternalSource.

Parameters:

  • name (String)

    @see name

  • params (Hash)

    @see params

  • podfile_path (String)

    @see podfile_path



60
61
62
63
64
# File 'lib/cocoapods/external_sources.rb', line 60

def initialize(name, params, podfile_path)
  @name = name
  @params = params
  @podfile_path = podfile_path
end

Instance Attribute Details

#nameString (readonly)

Returns the name of the Pod described by this external source.

Returns:

  • (String)

    the name of the Pod described by this external source.



44
45
46
# File 'lib/cocoapods/external_sources.rb', line 44

def name
  @name
end

#paramsHash{Symbol => String} (readonly)

Returns the hash representation of the external source.

Returns:

  • (Hash{Symbol => String})

    the hash representation of the external source.



49
50
51
# File 'lib/cocoapods/external_sources.rb', line 49

def params
  @params
end

#podfile_pathString (readonly)

Returns the path where the podfile is defined to resolve relative paths.

Returns:

  • (String)

    the path where the podfile is defined to resolve relative paths.



54
55
56
# File 'lib/cocoapods/external_sources.rb', line 54

def podfile_path
  @podfile_path
end

Instance Method Details

#==(other) ⇒ Bool

Returns whether an external source source is equal to another according to the #name and to the #params.

Returns:

  • (Bool)

    whether an external source source is equal to another according to the #name and to the #params.



69
70
71
72
# File 'lib/cocoapods/external_sources.rb', line 69

def ==(other)
  return false if other.nil?
  name == other.name && params == other.params
end

#descriptionString

Returns a string representation of the source suitable for UI.

Returns:

  • (String)

    a string representation of the source suitable for UI.



110
111
112
# File 'lib/cocoapods/external_sources.rb', line 110

def description
  raise "Abstract method"
end

#fetch(sandbox) ⇒ void

This method returns an undefined value.

Fetches the external source from the remote according to the params.

Parameters:

  • sandbox (Sandbox)

    the sandbox where the specification should be stored.



87
88
89
# File 'lib/cocoapods/external_sources.rb', line 87

def fetch(sandbox)
  raise "Abstract method"
end