Class: Pod::ExternalSources::AbstractExternalSource
- Inherits:
-
Object
- Object
- Pod::ExternalSources::AbstractExternalSource
- Defined in:
- lib/cocoapods/external_sources.rb
Overview
Abstract class that defines the common behaviour of external sources.
Direct Known Subclasses
GitSource, MercurialSource, PathSource, PodspecSource, SvnSource
Instance Attribute Summary collapse
-
#name ⇒ String
readonly
The name of the Pod described by this external source.
-
#params ⇒ Hash{Symbol => String}
readonly
The hash representation of the external source.
-
#podfile_path ⇒ String
readonly
The path where the podfile is defined to resolve relative paths.
Subclasses hooks collapse
-
#description ⇒ String
A string representation of the source suitable for UI.
-
#fetch(sandbox) ⇒ void
Fetches the external source from the remote according to the params.
Instance Method Summary collapse
- #==(other) ⇒ Bool
-
#initialize(name, params, podfile_path) ⇒ AbstractExternalSource
constructor
A new instance of AbstractExternalSource.
Constructor Details
#initialize(name, params, podfile_path) ⇒ AbstractExternalSource
Returns a new instance of AbstractExternalSource.
60 61 62 63 64 |
# File 'lib/cocoapods/external_sources.rb', line 60 def initialize(name, params, podfile_path) @name = name @params = params @podfile_path = podfile_path end |
Instance Attribute Details
#name ⇒ String (readonly)
Returns the name of the Pod described by this external source.
44 45 46 |
# File 'lib/cocoapods/external_sources.rb', line 44 def name @name end |
#params ⇒ Hash{Symbol => String} (readonly)
Returns the hash representation of the external source.
49 50 51 |
# File 'lib/cocoapods/external_sources.rb', line 49 def params @params end |
#podfile_path ⇒ String (readonly)
Returns the path where the podfile is defined to resolve relative paths.
54 55 56 |
# File 'lib/cocoapods/external_sources.rb', line 54 def podfile_path @podfile_path end |
Instance Method Details
#==(other) ⇒ Bool
69 70 71 72 |
# File 'lib/cocoapods/external_sources.rb', line 69 def ==(other) return false if other.nil? name == other.name && params == other.params end |
#description ⇒ String
Returns a string representation of the source suitable for UI.
110 111 112 |
# File 'lib/cocoapods/external_sources.rb', line 110 def description raise "Abstract method" end |
#fetch(sandbox) ⇒ void
This method returns an undefined value.
Fetches the external source from the remote according to the params.
87 88 89 |
# File 'lib/cocoapods/external_sources.rb', line 87 def fetch(sandbox) raise "Abstract method" end |